@@ -6,7 +6,7 @@ function(Loss, Capital, alpha=0.95, model=c("normal", "t-student", "both"), df=N
   S <- rowSums(L)
   
   # VaR alpha%: F^{-1}_{S}(p)=VaR
-  VaRp <- as.numeric(VaR(mean(S), varcov=var(S), alpha=alpha, model=model, df=df))
+  VaRp <- as.numeric(VaR(mean(S), variance =var(S), alpha=alpha, model=model, df=df))
   
   # Funcion indicador: S > VaR
   ind <- S>VaRp
